## Typing stubs for Send2Trash

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`Send2Trash`](https://github.com/arsenetar/send2trash) package. It can be used by type checkers
to check code that uses `Send2Trash`. This version of
`types-Send2Trash` aims to provide accurate annotations for
`Send2Trash==2.1.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/Send2Trash`](https://github.com/python/typeshed/tree/main/stubs/Send2Trash)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.19.1
* [pyright](https://github.com/microsoft/pyright) 1.1.408

It was generated from typeshed commit
[`b94c9e8e48f552b2f2b979b69937b0e4848675cf`](https://github.com/python/typeshed/commit/b94c9e8e48f552b2f2b979b69937b0e4848675cf).